#!/bin/bash -e
configDir=/etc/azsec/baseimage
# Pull in shared functions
source /usr/local/bin/shared-baseimage.sh
# Determine which OS Version we're using
if [ -z "OSMAJORVER" ]; then
    echo "Failed to pull in shared functions from /usr/local/bin/shared-baseimage.sh"
    exit 1
elif [ $OSMAJORVER -eq 12 ]; then
    # For 12.04, upgrade the kernel and install jdk as required by HDI
    TryAptInstall linux-generic-lts-trusty linux-image-generic-lts-trusty openjdk-7-jdk
fi
TryAptInstall unattended-upgrades azure-baseimage-patch
apt-get autoremove -y
updatedb
# Add DNS retries
echo "options timeout:1 attempts:5" >> /etc/resolvconf/resolv.conf.d/head
service resolvconf restart
# Disable lwresd, enable unscd
if [ -e /etc/nscd.conf ]; then
	apt-get remove -y libnss-lwres lwresd
	sed -i 's/lwres\s*//g' /etc/nsswitch.conf
	sed -i 's/\(^hosts:\s\+files\s\+\)/\1cache /g' /etc/nsswitch.conf
	sed -i 's/\(enable-cache\s\+hosts\s\+\)[a-z]\+/\1yes/g' /etc/nscd.conf
else
	echo "Could not find /etc/nscd.conf - skipping nscd config and leaving lwresd installed"
fi
# Disable console logging to prevent lock-ups on systems with > 15 CPUs
sed -i 's/\s*console=ttyS0//g' /etc/default/grub
update-grub
# Update dhcp timeout
sed -i 's/long=[0-9]*/long=240/g' /etc/init/cloud-init-nonet.conf
# Create JAVA_HOME variable for all users
JAVADIR=/usr/lib/jvm/java-7-openjdk-amd64
echo export JAVA_HOME=$JAVADIR >> /etc/profile
echo export JAVA_HOME=$JAVADIR >> /etc/skel/.bashrc
echo export JAVA_HOME=$JAVADIR >> /root/.bashrc
# Allow sudo to pull in /etc/environment in 14.04
if [ $OSMAJORVER -eq 14 ]; then
    echo "session    required   pam_env.so readenv=1" >> /etc/pam.d/sudo
fi

# Raise open file limit from 1024
echo "*  soft  nofile 10000" >> /etc/security/limits.conf
echo "*  hard  nofile 10000" >> /etc/security/limits.conf
echo "root  soft  nofile 10000" >> /etc/security/limits.conf
echo "root  hard  nofile 10000" >> /etc/security/limits.conf
echo "session required pam_limits.so" >> /etc/pam.d/common-session

# Apply baseline security configuration
/usr/local/bin/apply-secbaseline.sh

# Enable scanners
azsec-config.py -n avscan -c P1D
azsec-config.py -n bscan -c P1D
azsec-config.py -n pscan -c P1D
azsec-config.py -n swscan -c P1D
